package net.wanji.com.service.controller.impl;

import cn.hutool.core.util.HexUtil;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import net.wanji.com.cache.CrossInfoCache;
import net.wanji.com.common.constants.Constants;
import net.wanji.com.netty.NettyClient;
import net.wanji.com.pojo.dtconvert.*;
import net.wanji.com.pojo.netty.MessageResultPojo;
import net.wanji.com.service.controller.StaticInfoService;
import net.wanji.common.enums.BaseEnum;
import net.wanji.databus.dao.entity.CrossSchedulesPO;
import net.wanji.databus.dto.CrossInfoDTO;
import net.wanji.databus.dto.CrossSchedulesDTO;
import net.wanji.databus.dto.PlanSectionDTO;
import net.wanji.databus.dto.SchemePhaseLightsDTO;
import net.wanji.databus.po.CrossInfoPO;
import net.wanji.databus.vo.PlanSectionVO;
import net.wanji.databus.vo.SchemePhaseLightsVO;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @author duanruiming
 * @date 2023/05/08 17:29
 */
@Service
@RequiredArgsConstructor
@Slf4j
public class DTStaticInfoServiceImpl implements StaticInfoService {

    private final CrossInfoCache crossInfoCache;

    @Override
    public String getBeanMark() {
        return BaseEnum.VendorTypeEnum.DT.getNick();
    }

    @Override
    public List<CrossInfoPO> crossBasicInfo(CrossInfoDTO crossInfoDTO) throws Exception {
        return null;
    }

    @Override
    public SchemePhaseLightsVO schemePhaseLights(SchemePhaseLightsDTO schemePhaseLightsDTO) throws Exception {
        SchemePhaseLightsVO schemePhaseLightsVO = new SchemePhaseLightsVO();
        String crossId = schemePhaseLightsDTO.getCrossId();
        CrossInfoPO crossInfo = crossInfoCache.getCrossInfoCache().get(crossId);
        List<PhaseInfoPojo> phaseInfoPojos = getPhaseInfo(crossInfo);
        List<LightsInfoPojo> lightsInfoPojos = getLightsInfo(crossInfo);
        List<PhaseStageInfoPojo> phaseStageInfoPojos = getPhaseStageInfo(crossInfo);
        List<SchemeInfoPojo> schemeInfoPojos = getSchemeInfo(crossInfo);
        return schemePhaseLightsVO;
    }

    private List<SchemeInfoPojo> getSchemeInfo(CrossInfoPO crossInfo) {
        String message = String.format(Constants.COMMAND_COMMON, Constants.COMMAND_QUERY, Constants.COMMAND_SCHME_CONFIG);
        String schemeSign = Constants.COMMAND_SCHME_CONFIG.concat(Constants.COMMAND_QUERY_REPLY);
        String schemeHex = Constants.buildMessage(message);
        MessageResultPojo resultPojo = NettyClient.sendMessage(crossInfo.getIp(), crossInfo.getPort(), schemeHex, schemeSign, 300);
        return getSchemeInfoPojos(resultPojo);
    }

    private List<SchemeInfoPojo> getSchemeInfoPojos(MessageResultPojo resultPojo) {
        List<SchemeInfoPojo> schemeInfoPojos = new ArrayList<>();
        if (Objects.nonNull(resultPojo) && StringUtils.isNotBlank(resultPojo.getHexMessageResult())) {
            String hexMessageResult = resultPojo.getHexMessageResult();
            Map<Integer, List<String>> schemeIdParamMap = getSchemeIdParamMap(hexMessageResult);
            schemeInfoPojos = paramMapConvert(schemeIdParamMap);
        }
        return schemeInfoPojos;
    }

    private List<SchemeInfoPojo> paramMapConvert(Map<Integer, List<String>> schemeIdParamMap) {
        List<SchemeInfoPojo> schemeInfoPojos = new ArrayList<>();
        for (Map.Entry<Integer, List<String>> entry : schemeIdParamMap.entrySet()) {
            SchemeInfoPojo schemeInfoPojo = new SchemeInfoPojo();
            Integer schemeId = entry.getKey();
            schemeInfoPojo.setSchemeId(schemeId);
            List<String> value = entry.getValue();
            schemeInfoPojo.setCrossId(HexUtil.hexToInt(value.get(0)));
            schemeInfoPojo.setCycle(HexUtil.hexToInt(value.get(1)));
            schemeInfoPojo.setHarmonizeId(HexUtil.hexToInt(value.get(2)));
            schemeInfoPojo.setOffset(HexUtil.hexToInt(value.get(3)));
            String phaseChainHex = value.get(4);
            List<Integer> phaseList = getListFromHex(phaseChainHex, 2, "00");
            schemeInfoPojo.setPhaseList(phaseList);

            String phaseTimeChainHex = value.get(5);
            List<Integer> phaseTimeList = getListFromHex(phaseTimeChainHex, 4, "0000");
            schemeInfoPojo.setPhaseTimeChain(phaseTimeList);

            String phaseTypeChainHex = value.get(6);
            List<Integer> phaseTypeList = getListFromHex(phaseTypeChainHex, 2, "00");
            schemeInfoPojo.setPhaseTypeChain(phaseTypeList);

            schemeInfoPojos.add(schemeInfoPojo);
        }
        return schemeInfoPojos.stream().filter(schemeInfoPojo -> schemeInfoPojo.getCycle() != 0).collect(Collectors.toList());
    }

    /**
     * 通用处理字符串多字节转int，固定长度
     * 00000000000000000000000008070605 ==>  5 6 7 8
     *
     * @param hex
     * @param offset
     * @param ignoreStr
     * @return
     */
    public static List<Integer> getListFromHex(String hex, int offset, String ignoreStr) {
        List<Integer> list = new ArrayList<>();
        for (int i = 0; i < hex.length() / offset; i++) {
            String phaseTypeHex = hex.substring(i * offset, i * offset + offset);
            if (!StringUtils.equals(ignoreStr, phaseTypeHex)) {
                list.add(HexUtil.hexToInt(phaseTypeHex));
            }
        }
        return list;
    }

    private static Map<Integer, List<String>> getSchemeIdParamMap(String hexMessageResult) {
        Map<Integer, List<String>> schemeIdParamMap = new HashMap<>();
        if (StringUtils.isNotBlank(hexMessageResult)) {
            String body = hexMessageResult.substring(32, hexMessageResult.length() - 2);
            int schemeSize = body.length() / 228;
            String matchStr = "0902%s%s";
            int schemeId = 0;
            for (int i = 0; i < schemeSize; i++) {
                ++schemeId;
                List<String> paramList = new ArrayList<>();
                // 属性ID数量
                for (int j = 2; j < 9; j++) {
                    String currentMatchStr = String.format(matchStr, String.format("%02x", j), String.format("%02x", schemeId));
                    int paramStartIndex = body.indexOf(currentMatchStr) + 8;
                    String param = null;
                    if (j == 2 || j == 4) {
                        param = body.substring(paramStartIndex, paramStartIndex + 2);
                    } else if (j == 3) {
                        param = body.substring(paramStartIndex, paramStartIndex + 8);
                    } else if (j == 5) {
                        param = body.substring(paramStartIndex, paramStartIndex + 4);
                    } else if (j == 6 || j == 8) {
                        param = body.substring(paramStartIndex, paramStartIndex + 32);
                    } else if (j == 7) {
                        param = body.substring(paramStartIndex, paramStartIndex + 64);
                    }
                    paramList.add(param);
                }
                schemeIdParamMap.put(schemeId, paramList);
            }
        }
        return schemeIdParamMap;
    }

    private List<PhaseStageInfoPojo> getPhaseStageInfo(CrossInfoPO crossInfo) {
        String message = String.format(Constants.COMMAND_COMMON, Constants.COMMAND_QUERY, Constants.COMMAND_PHASE_STAGE_CONFIG);
        String phaseStageSign = Constants.COMMAND_PHASE_STAGE_CONFIG.concat(Constants.COMMAND_QUERY_REPLY);
        String phaseStageHex = Constants.buildMessage(message);
        MessageResultPojo resultPojo = NettyClient.sendMessage(crossInfo.getIp(), crossInfo.getPort(), phaseStageHex, phaseStageSign, 300);
        return getPhaseStageInfoPojos(resultPojo);
    }

    private List<PhaseStageInfoPojo> getPhaseStageInfoPojos(MessageResultPojo resultPojo) {
        List<PhaseStageInfoPojo> phaseStageInfoPojos = new ArrayList<>();
        if (Objects.nonNull(resultPojo) && StringUtils.isNotBlank(resultPojo.getHexMessageResult())) {
            String hexMessageResult = resultPojo.getHexMessageResult();
            String body = hexMessageResult.substring(32, hexMessageResult.length() - 2);
            int phaseStageSize = body.length() / 308;
            for (int i = 0; i < phaseStageSize; i++) {
                String phaseStageHex = body.substring(i * 308 + 8, i * 308 + 24);
                StringBuffer sb = new StringBuffer();
                for (int j = 0; j < phaseStageHex.length() / 2; j++) {
                    String hex = phaseStageHex.substring(j * 2, j * 2 + 2);
                    String binary = Integer.toBinaryString(HexUtil.hexToInt(hex));
                    sb.append(StringUtils.leftPad(binary, 8, '0'));
                }
                List<Integer> phaseList = new ArrayList<>();
                char[] chars = sb.reverse().toString().toCharArray();
                for (int k = 0; k < chars.length; k++) {
                    if (chars[k] == '1') {
                        phaseList.add(k + 1);
                    }
                }
                if (CollectionUtils.isEmpty(phaseList)) {
                    continue;
                }
                PhaseStageInfoPojo phaseStageInfoPojo = new PhaseStageInfoPojo();
                phaseStageInfoPojo.setPhaseStageId(i + 1);
                phaseStageInfoPojo.setPhaseList(phaseList);
                phaseStageInfoPojos.add(phaseStageInfoPojo);
            }
        }
        return phaseStageInfoPojos;
    }

    private List<LightsInfoPojo> getLightsInfo(CrossInfoPO crossInfo) {
        String message = String.format(Constants.COMMAND_COMMON, Constants.COMMAND_QUERY, Constants.COMMAND_LIGHT_CONFIG);
        String lightResultSign = Constants.COMMAND_LIGHT_CONFIG.concat(Constants.COMMAND_QUERY_REPLY);
        String lightsHex = Constants.buildMessage(message);
        MessageResultPojo resultPojo = NettyClient.sendMessage(crossInfo.getIp(), crossInfo.getPort(), lightsHex, lightResultSign, 300);
        return getLightsInfoPojos(resultPojo);
    }

    private static List<LightsInfoPojo> getLightsInfoPojos(MessageResultPojo resultPojo) {
        List<LightsInfoPojo> lightsInfoPojos = new ArrayList<>();
        if (Objects.nonNull(resultPojo) && StringUtils.isNotBlank(resultPojo.getHexMessageResult())) {
            String hexMessageResult = resultPojo.getHexMessageResult();
            String body = hexMessageResult.substring(32, hexMessageResult.length() - 2);
            int lightsSize = body.length() / 14;
            for (int i = 0; i < lightsSize; i++) {
                LightsInfoPojo lightsInfoPojo = new LightsInfoPojo();
                int lightId = HexUtil.hexToInt(body.substring(i * 14 + 6, i * 14 + 8));
                int type = HexUtil.hexToInt(body.substring(i * 14 + 8, i * 14 + 10));
                lightsInfoPojo.setLightId(lightId);
                lightsInfoPojo.setType(type);
                lightsInfoPojos.add(lightsInfoPojo);
            }
        }
        return lightsInfoPojos;
    }

    /**
     * 上载相位信息
     *
     * @param crossInfo
     */
    private List<PhaseInfoPojo> getPhaseInfo(CrossInfoPO crossInfo) {
        String message = String.format(Constants.COMMAND_COMMON, Constants.COMMAND_QUERY, Constants.COMMAND_PHASE_CONFIG);
        String phaseResultSign = Constants.COMMAND_PHASE_CONFIG.concat(Constants.COMMAND_QUERY_REPLY);
        String phaseHex = Constants.buildMessage(message);
        MessageResultPojo resultPojo = NettyClient.sendMessage(crossInfo.getIp(), crossInfo.getPort(), phaseHex, phaseResultSign, 300);
        Map<Integer, List<String>> phaseIdParamsMap = getHexPhaseParamMap(resultPojo);
        return getPhaseInfoPojos(phaseIdParamsMap);
    }

    private static List<PhaseInfoPojo> getPhaseInfoPojos(Map<Integer, List<String>> phaseIdParamsMap) {
        List<PhaseInfoPojo> phaseInfoPojos = new ArrayList<>();
        for (Map.Entry<Integer, List<String>> item : phaseIdParamsMap.entrySet()) {
            PhaseInfoPojo phaseInfoPojo = new PhaseInfoPojo();
            Integer phaseId = item.getKey();
            List<String> phaseParamList = item.getValue();
            if (!CollectionUtils.isEmpty(phaseParamList)) {
                String lightsIdHex = phaseParamList.get(0);
                StringBuffer sb = new StringBuffer();
                for (int i = 0; i < lightsIdHex.length() / 2; i++) {
                    String hex = lightsIdHex.substring(i * 2, i * 2 + 2);
                    String binary = Integer.toBinaryString(HexUtil.hexToInt(hex));
                    sb.append(StringUtils.leftPad(binary, 8, '0'));
                }
                phaseInfoPojo.setPhaseId(phaseId);
                phaseInfoPojo.setLights(sb.reverse().toString().indexOf("1"));
                phaseInfoPojo.setGreenTime(HexUtil.hexToInt(phaseParamList.get(2)));
                phaseInfoPojo.setGreenFlashTime(HexUtil.hexToInt(phaseParamList.get(4)));
                phaseInfoPojo.setYellowTime(HexUtil.hexToInt(phaseParamList.get(6)));
                phaseInfoPojo.setRedTime(HexUtil.hexToInt(phaseParamList.get(8)));
                phaseInfoPojo.setYellowFlashTime(HexUtil.hexToInt(phaseParamList.get(13)));
                phaseInfoPojo.setMinGreenTime(HexUtil.hexToInt(phaseParamList.get(25)));
                phaseInfoPojo.setMaxGreenTime(HexUtil.hexToInt(phaseParamList.get(26)));
                phaseInfoPojo.setMaxGreenTime2(HexUtil.hexToInt(phaseParamList.get(27)));
                phaseInfoPojo.setExtendGreenTime(HexUtil.hexToInt(phaseParamList.get(28)));
                phaseInfoPojos.add(phaseInfoPojo);
            }
        }
        // 过滤掉未配置的相位
        return phaseInfoPojos.stream().filter(phaseInfoPojo -> phaseInfoPojo.getRedTime() != 0).collect(Collectors.toList());
    }

    private static Map<Integer, List<String>> getHexPhaseParamMap(MessageResultPojo resultPojo) {
        Map<Integer, List<String>> phaseIdParamsMap = new HashMap<>();
        if (Objects.nonNull(resultPojo) && StringUtils.isNotBlank(resultPojo.getHexMessageResult())) {
            String hexMessageResult = resultPojo.getHexMessageResult();
            String body = hexMessageResult.substring(32, hexMessageResult.length() - 2);
            int phaseSize = body.length() / 456; // 456一组相位数据
            String matchStr = "0402%s%s";
            for (int i = 0; i < phaseSize - 1; i++) {
                int paramIndex = 0;
                int count = 1;
                List<String> paramList = new ArrayList<>();
                for (int j = 0; j < 31; j++) {
                    ++count;
                    // 0402 + 属性序号count + 相位序号i
                    String currentMatchStr = String.format(matchStr, String.format("%02x", count), String.format("%02x", i + 1));
                    paramIndex = body.indexOf(currentMatchStr) + 8;
                    String param = "";
                    if (count == 2) {
                        param = body.substring(paramIndex, paramIndex + 16);
                    } else if (count > 2 && count < 27) {
                        param = body.substring(paramIndex, paramIndex + 2);
                    } else if (count >= 27 && count < 31) {
                        param = body.substring(paramIndex, paramIndex + 4);
                    } else if (count == 31) {
                        param = body.substring(paramIndex, paramIndex + 16);
                    }
                    if (StringUtils.isBlank(param)) {
                        continue;
                    }
                    paramList.add(param);
                }
                phaseIdParamsMap.put(i + 1, paramList);
            }
        }
        return phaseIdParamsMap;
    }

    @Override
    public List<PlanSectionVO> planSection(PlanSectionDTO planSectionDTO) throws Exception {
        String crossId = planSectionDTO.getCrossId();
        CrossInfoPO crossInfoPO = crossInfoCache.getCrossInfoCache().get(crossId);
        List<DailyPlanInfoPojo> dailyPlanInfoPojos = getDailyPlanInfo(crossInfoPO);
        return null;
    }

    private List<DailyPlanInfoPojo> getDailyPlanInfo(CrossInfoPO crossInfoPO) {
        String message = String.format(Constants.COMMAND_COMMON, Constants.COMMAND_QUERY, Constants.COMMAND_DAILYPLAN_CONFIG);
        String dailyPlanSign = Constants.COMMAND_DAILYPLAN_CONFIG.concat(Constants.COMMAND_QUERY_REPLY);
        String dailyPlanHex = Constants.buildMessage(message);
        MessageResultPojo resultPojo = NettyClient.sendMessage(crossInfoPO.getIp(), crossInfoPO.getPort(), dailyPlanHex, dailyPlanSign, 300);
        return getDailyPlanPojos(resultPojo);
    }

    private List<DailyPlanInfoPojo> getDailyPlanPojos(MessageResultPojo resultPojo) {
        List<DailyPlanInfoPojo> dailyPlanInfoPojos = new ArrayList<>();
        if (Objects.nonNull(resultPojo) && StringUtils.isNotBlank(resultPojo.getHexMessageResult())) {
            HashMap<Integer, List<String>> paramMap = new HashMap<>();
            String hexMessageResult = resultPojo.getHexMessageResult();
            String body = hexMessageResult.substring(32, hexMessageResult.length() - 2);
            int dailyPlanSize = body.length() / 434;
            String matchStr = "0b02%s%s";
            for (int i = 0; i < dailyPlanSize; i++) {
                int paramIndex = 0;
                // 4个属性
                List<String> paramList = new ArrayList<>();
                for (int j = 2; j < 6; j++) {
                    String currentMatchStr = String.format(matchStr, String.format("%02x", j), String.format("%02x", i + 1));
                    paramIndex = body.indexOf(currentMatchStr) + 8;
                    String param = "";
                    if (j == 2) {
                        param = body.substring(paramIndex, paramIndex + 2);
                    } else if (j == 3) {
                        param = body.substring(paramIndex, paramIndex + 192);
                    } else {
                        param = body.substring(paramIndex, paramIndex + 96);
                    }
                    paramList.add(param);
                }
                paramMap.put(i + 1, paramList);
            }
            dailyPlanInfoPojos = convertDailyPlanPojos(paramMap);
        }
        return dailyPlanInfoPojos;
    }

    private List<DailyPlanInfoPojo> convertDailyPlanPojos(HashMap<Integer, List<String>> paramMap) {
        List<DailyPlanInfoPojo> dailyPlanInfoPojos = new ArrayList<>();
        for (Map.Entry<Integer, List<String>> entry : paramMap.entrySet()) {
            Integer dailyPlanId = entry.getKey();
            List<String> value = entry.getValue();
            if (!CollectionUtils.isEmpty(value)) {
                DailyPlanInfoPojo dailyPlanInfoPojo = new DailyPlanInfoPojo();
                dailyPlanInfoPojo.setDailyPlanId(dailyPlanId);
                dailyPlanInfoPojo.setCrossId(HexUtil.hexToInt(value.get(0)));
                List<Integer> listFromHex = getListFromHex(value.get(1), 2, "");
                Collections.reverse(listFromHex);
                List<String> startTimeChain = new ArrayList<>();
                for (int i = 0; i < listFromHex.size() / 2; i++) {
                    int minute = listFromHex.get(i * 2);
                    int hour = listFromHex.get(i * 2 + 1);
                    // 只有第一个时段可以为00：00
                    if ((i != 0 && hour == 0)) {
                        continue;
                    }
                    startTimeChain.add(StringUtils.join(String.format("%02d", hour), ":", String.format("%02d", minute)));
                }
                dailyPlanInfoPojo.setStartTimeChain(startTimeChain);

                List<Integer> schemeIdChain = getListFromHex(value.get(2), 2, "00");
                dailyPlanInfoPojo.setSchemeIdChain(schemeIdChain);
                // 21 ==> 33 定周期
                List<Integer> controlModeChain = getListFromHex(value.get(3), 2, "00");
                dailyPlanInfoPojo.setControlModelChain(controlModeChain);
                dailyPlanInfoPojos.add(dailyPlanInfoPojo);
            }
        }
        return dailyPlanInfoPojos.stream().filter(dailyPlanInfoPojo -> !CollectionUtils.isEmpty(dailyPlanInfoPojo.getSchemeIdChain())).collect(Collectors.toList());
    }

    @Override
    public List<CrossSchedulesPO> crossSchedules(CrossSchedulesDTO crossSchedulesDTO) throws Exception {
        String crossId = crossSchedulesDTO.getCrossId();
        CrossInfoPO crossInfoPO = crossInfoCache.getCrossInfoCache().get(crossId);
        String message = String.format(Constants.COMMAND_COMMON, Constants.COMMAND_QUERY, Constants.COMMAND_SCHEDULE_CONFIG);
        String scheduleSign = Constants.COMMAND_SCHEDULE_CONFIG.concat(Constants.COMMAND_QUERY_REPLY);
        String scheduleHex = Constants.buildMessage(message);
        MessageResultPojo resultPojo = NettyClient.sendMessage(crossInfoPO.getIp(), crossInfoPO.getPort(), scheduleHex, scheduleSign, 300);
        List<ScheduleInfoPojo> scheduleInfoPojos = getSchedulePojos(resultPojo);
        return null;
    }

    private List<ScheduleInfoPojo> getSchedulePojos(MessageResultPojo resultPojo) {
        List<ScheduleInfoPojo> scheduleInfoPojos = new ArrayList<>();
        if (Objects.nonNull(resultPojo) && StringUtils.isNotBlank(resultPojo.getHexMessageResult())) {
            HashMap<Integer, List<String>> paramMap = new HashMap<>();
            String hexMessageResult = resultPojo.getHexMessageResult();
            String body = hexMessageResult.substring(32, hexMessageResult.length() - 2);
            int scheduleSize = body.length() / 92;
            String matchStr = "0c02%s%s";
            int paramIndex = 0;
            for (int i = 0; i < scheduleSize; i++) {
                List<String> paramList = new ArrayList<>();
                for (int j = 2; j < 8; j++) {
                    String currentMatchStr = String.format(matchStr, String.format("%02x", j), String.format("%02x", i + 1));
                    paramIndex = body.indexOf(currentMatchStr) + 8;
                    String param = "";
                    if (j == 5) {
                        param = body.substring(paramIndex, paramIndex + 4);
                    } else if (j == 6) {
                        param = body.substring(paramIndex, paramIndex + 8);
                    } else {
                        param = body.substring(paramIndex, paramIndex + 2);
                    }
                    paramList.add(param);
                }
                paramMap.put(i + 1, paramList);
            }
            scheduleInfoPojos = convertSchedulePojos(paramMap);

        }
        return scheduleInfoPojos;
    }

    private List<ScheduleInfoPojo> convertSchedulePojos(HashMap<Integer, List<String>> paramMap) {
        List<ScheduleInfoPojo> scheduleInfoPojos = new ArrayList<>();
        for (Map.Entry<Integer, List<String>> entry : paramMap.entrySet()) {
            Integer scheduleId = entry.getKey();
            List<String> value = entry.getValue();
            if (!CollectionUtils.isEmpty(value)) {
                ScheduleInfoPojo scheduleInfoPojo = new ScheduleInfoPojo();
                scheduleInfoPojo.setScheduleId(scheduleId);
                scheduleInfoPojo.setCrossId(HexUtil.hexToInt(value.get(0)));
                scheduleInfoPojo.setPriority(HexUtil.hexToInt(value.get(1)));
                String weekStr = Integer.toBinaryString(HexUtil.hexToInt(value.get(2)));
                List<Integer> weekList = new ArrayList<>();
                for (int i = 0; i < weekStr.length(); i++) {
                    String week = weekStr.substring(i, i + 1);
                    if (StringUtils.equals("1", week)) {
                        weekList.add(weekStr.length() - i);
                    }
                }
                scheduleInfoPojo.setWeek(weekList);

                String monthStr = Integer.toBinaryString(HexUtil.hexToInt(value.get(3)));
                List<Integer> monthList = new ArrayList<>();
                for (int i = 0; i < monthStr.length(); i++) {
                    String month = monthStr.substring(i, i + 1);
                    if (StringUtils.equals("1", month)) {
                        monthList.add(monthStr.length() - i);
                    }
                }
                scheduleInfoPojo.setMonth(monthList);

                String dayStr = Integer.toBinaryString(HexUtil.hexToInt(value.get(4)));
                List<Integer> dayList = new ArrayList<>();
                for (int i = 0; i < dayStr.length(); i++) {
                    String day = dayStr.substring(i, i + 1);
                    if (StringUtils.equals("1", day)) {
                        dayList.add(dayStr.length() - i);
                    }
                }
                scheduleInfoPojo.setDay(dayList);
                scheduleInfoPojo.setDailyPlanId(HexUtil.hexToInt(value.get(5)));
                scheduleInfoPojos.add(scheduleInfoPojo);
            }
        }
        List<ScheduleInfoPojo> filter = scheduleInfoPojos.stream().filter(scheduleInfoPojo -> Objects.nonNull(scheduleInfoPojo.getDailyPlanId())).collect(Collectors.toList());
        return filter;
    }

    @Override
    public SchemePhaseLightsVO buildSchemePhaseLightsResponse(SchemePhaseLightsDTO schemePhaseLightsDTO) {
        return null;
    }

    @Override
    public PlanSectionVO buildPlanSectionResponse(String crossId) {
        return null;
    }

    @Override
    public PlanSectionVO buildPlanSectionResponse(String crossId, Integer planNo) {
        return null;
    }

    @Override
    public List<CrossSchedulesPO> buildCrossSchedulesResponse(List<String> crossIdList) {
        return null;
    }
}
